@@ -13,6 +13,7 @@ from weaverbird.backends.mongo_translator.steps.convert import translate_convert
 from weaverbird.backends.mongo_translator.steps.cumsum import translate_cumsum
 from weaverbird.backends.mongo_translator.steps.custom import translate_custom
 from weaverbird.backends.mongo_translator.steps.date_extract import translate_date_extract
+from weaverbird.backends.mongo_translator.steps.date_granularity import translate_date_granularity
 from weaverbird.backends.mongo_translator.steps.delete import translate_delete
 from weaverbird.backends.mongo_translator.steps.domain import translate_domain
 from weaverbird.backends.mongo_translator.steps.duplicate import translate_duplicate
@@ -64,6 +65,7 @@ mongo_step_translator: dict[str, Callable[[Any], list]] = {
     "cumsum": translate_cumsum,
     "custom": translate_custom,
     "dateextract": translate_date_extract,
+    "dategranularity": translate_date_granularity,
     "delete": translate_delete,
     "domain": translate_domain,
     "duplicate": translate_duplicate,
