@@ -1,12 +1,10 @@
-from typing import List
-
 from weaverbird.backends.mongo_translator.steps.types import MongoStep
 from weaverbird.pipeline.steps import DuplicateStep
 
 
-def translate_duplicate(step: DuplicateStep) -> List[MongoStep]:
+def translate_duplicate(step: DuplicateStep) -> list[MongoStep]:
     return [
         {
-            '$addFields': {(step.new_column_name): f'${step.column}'},
+            "$addFields": {(step.new_column_name): f"${step.column}"},
         }
     ]
