@@ -5,11 +5,7 @@ from weaverbird.pipeline.steps import EvolutionStep
 
 
 def translate_evolution(step: EvolutionStep) -> list[MongoStep]:
-    new_column = (
-        step.new_column
-        if step.new_column
-        else f"{step.value_col}_EVOL_{step.evolution_format.upper()}"
-    )
+    new_column = step.new_column if step.new_column else f"{step.value_col}_EVOL_{step.evolution_format.upper()}"
     error_msg = "Error: More than one previous date found for the specified index columns"
     add_field_result: dict[str, Any] = {}
 
@@ -31,7 +27,7 @@ def translate_evolution(step: EvolutionStep) -> list[MongoStep]:
                 "default": {
                     "$divide": [
                         {"$subtract": [f"${step.value_col}", "$_VQB_VALUE_PREV"]},
-                        "$_VQB_VALUE_PREV",
+                        {"$abs": "$_VQB_VALUE_PREV"},
                     ],
                 },
             },
@@ -56,9 +52,7 @@ def translate_evolution(step: EvolutionStep) -> list[MongoStep]:
         {
             "$facet": {
                 "_VQB_ORIGINALS": [{"$project": {"_id": 0}}],
-                "_VQB_COPIES_ARRAY": [
-                    {"$group": {"_id": None, "_VQB_ALL_DOCS": {"$push": "$$ROOT"}}}
-                ],
+                "_VQB_COPIES_ARRAY": [{"$group": {"_id": None, "_VQB_ALL_DOCS": {"$push": "$$ROOT"}}}],
             },
         },
         {"$unwind": "$_VQB_ORIGINALS"},
@@ -82,7 +76,11 @@ def translate_evolution(step: EvolutionStep) -> list[MongoStep]:
                         "cond": {
                             "$and": [
                                 {"$eq": ["$_VQB_DATE_PREV", f"$$item.{step.date_col}"]},
-                                {"$eq": [f"${col}", f"$$item.{col}"] for col in step.index_columns},
+                                *(
+                                    {"$eq": [f"${col}", f"$$item.{col}"]}
+                                    for col in step.index_columns
+                                    if col != step.date_col
+                                ),
                             ],
                         },
                     },
