@@ -1,3 +1,5 @@
+from typing import Any, Literal
+
 from weaverbird.backends.mongo_translator.steps.formula import build_mongo_formula_tree
 from weaverbird.backends.mongo_translator.steps.types import MongoStep
 from weaverbird.backends.mongo_translator.utils import build_cond_expression
@@ -5,6 +7,11 @@ from weaverbird.pipeline.formula_ast.eval import FormulaParser
 from weaverbird.pipeline.steps.ifthenelse import IfThenElse, IfthenelseStep
 
 
+def _default_to_null(expr: Any) -> dict[Literal["$ifNull"], list[Any]]:
+    """Makes the passed expression default to NULL if not defined"""
+    return {"$ifNull": [expr, None]}
+
+
 def transform_ifthenelse_step(step: IfThenElse) -> MongoStep:
     else_expr: dict | str | int | float | bool
     if isinstance(step.else_value, IfThenElse):
@@ -16,12 +23,8 @@ def transform_ifthenelse_step(step: IfThenElse) -> MongoStep:
             else_expr = step.else_value
 
     if_expr = build_cond_expression(step.condition)
-    try:
-        then_expr = build_mongo_formula_tree(FormulaParser(str(step.then)).parse())
-    except SyntaxError:  # step is a badly formatted string
-        return step.then
-
-    return {"$cond": {"if": if_expr, "then": then_expr, "else": else_expr}}
+    then_expr = build_mongo_formula_tree(FormulaParser(str(step.then)).parse())
+    return {"$cond": {"if": if_expr, "then": _default_to_null(then_expr), "else": _default_to_null(else_expr)}}
 
 
 def translate_ifthenelse(step: IfthenelseStep) -> list[MongoStep]:
