@@ -9,27 +9,56 @@ def _get_quantile(n: int, p: int) -> MongoStep:
     - the median is the first quantile of order 2.
     - the last decile is the 9-th quantile of order 10.
     """
+
     return {
-        "$avg": [
+        "$cond": [
+            # if
+            {
+                "$eq": [
+                    {
+                        "$mod": [
+                            {
+                                "$avg": [
+                                    {"$multiply": [{"$divide": ["$count", p]}, n]},
+                                    {"$subtract": [{"$multiply": [{"$divide": ["$count", p]}, n]}, 1]},
+                                ]
+                            },
+                            1,
+                        ]
+                    },
+                    0,
+                ]
+            },
+            # then
             {
                 "$arrayElemAt": [
                     "$data",
                     {
-                        "$trunc": {
-                            "$subtract": [{"$multiply": [{"$divide": ["$count", p]}, n]}, 1],
-                        },
+                        "$avg": [
+                            {"$multiply": [{"$divide": ["$count", p]}, n]},
+                            {"$subtract": [{"$multiply": [{"$divide": ["$count", p]}, n]}, 1]},
+                        ]
                     },
-                ],
+                ]
             },
+            # else
             {
-                "$arrayElemAt": [
-                    "$data",
+                "$avg": [
                     {
-                        "$trunc": {"$multiply": [{"$divide": ["$count", p]}, n]},
+                        "$arrayElemAt": [
+                            "$data",
+                            {"$trunc": {"$multiply": [{"$divide": ["$count", p]}, n]}},
+                        ]
                     },
-                ],
+                    {
+                        "$arrayElemAt": [
+                            "$data",
+                            {"$trunc": {"$subtract": [{"$multiply": [{"$divide": ["$count", p]}, n]}, 1]}},
+                        ]
+                    },
+                ]
             },
-        ],
+        ]
     }
 
 
@@ -38,11 +67,7 @@ def _need_to_compute_column_square(step: StatisticsStep) -> bool:
 
 
 def _need_to_compute_average(step: StatisticsStep) -> bool:
-    return (
-        "average" in step.statistics
-        or "variance" in step.statistics
-        or "standard deviation" in step.statistics
-    )
+    return "average" in step.statistics or "variance" in step.statistics or "standard deviation" in step.statistics
 
 
 def _need_to_sort(step: StatisticsStep) -> bool:
@@ -72,11 +97,7 @@ def translate_statistics(step: StatisticsStep) -> list[MongoStep]:
             "$project": {
                 **{col: 1 for col in step.groupby_columns},
                 "column": f"${step.column}",
-                **(
-                    {"column_square": {"$pow": [f"${step.column}", 2]}}
-                    if _need_to_compute_column_square(step)
-                    else {}
-                ),
+                **({"column_square": {"$pow": [f"${step.column}", 2]}} if _need_to_compute_column_square(step) else {}),
             },
         },
         {
@@ -92,11 +113,7 @@ def translate_statistics(step: StatisticsStep) -> list[MongoStep]:
                 **({"count": {"$sum": 1}} if _need_to_count(step) else {}),
                 **({"max": {"$max": "$column"}} if "max" in step.statistics else {}),
                 **({"min": {"$min": "$column"}} if "min" in step.statistics else {}),
-                **(
-                    {"average_sum_square": {"$avg": "$column_square"}}
-                    if _need_to_compute_column_square(step)
-                    else {}
-                ),
+                **({"average_sum_square": {"$avg": "$column_square"}} if _need_to_compute_column_square(step) else {}),
                 **({"average": {"$avg": "$column"}} if _need_to_compute_average(step) else {}),
             },
         },
@@ -108,9 +125,7 @@ def translate_statistics(step: StatisticsStep) -> list[MongoStep]:
                 **{statistic: _STATISTICS_FORMULA[statistic] for statistic in step.statistics},
                 #  quantiles
                 **{
-                    quantile.label
-                    if quantile.label
-                    else f"{quantile.nth}-th {quantile.order}-quantile": _get_quantile(
+                    quantile.label if quantile.label else f"{quantile.nth}-th {quantile.order}-quantile": _get_quantile(
                         quantile.nth, quantile.order
                     )
                     for quantile in step.quantiles
