@@ -6,11 +6,7 @@ from weaverbird.pipeline.steps import TotalsStep
 
 def combinations(iterable: list) -> list:
     """combinations([1,2,3]) --> (1,) (2,) (3,) (1,2) (1,3) (2,3) (1,2,3)"""
-    return list(
-        itertools.chain.from_iterable(
-            itertools.combinations(iterable, r) for r in range(1, len(iterable) + 1)
-        )
-    )
+    return list(itertools.chain.from_iterable(itertools.combinations(iterable, r) for r in range(1, len(iterable) + 1)))
 
 
 def column_map(s: list[str]) -> dict[str, str]:
@@ -27,7 +23,7 @@ def translate_totals(step: TotalsStep) -> list[MongoStep]:
     # get combinations, remove last combo (most granular combination of columns
     # so not useful to compute total rows) and add an empty tuple (to compute the grand total)
     combos: list[tuple] = combinations(to_combine)[:-1]
-    combos.append(tuple())
+    combos.append(())
 
     for agg_step in step.aggregations:
         for i in range(len(agg_step.columns)):
@@ -62,9 +58,7 @@ def translate_totals(step: TotalsStep) -> list[MongoStep]:
                 else:
                     aggs[aggregated_col] = {f"${agg_func}": f"${value_col}"}
 
-        add_fields_to_add_to_pipeline = (
-            [{"$addFields": count_distinct_add_fields}] if count_distinct_add_fields else []
-        )
+        add_fields_to_add_to_pipeline = [{"$addFields": count_distinct_add_fields}] if count_distinct_add_fields else []
 
         facet[f"combo_{i}"] = [
             {
