@@ -1,6 +1,6 @@
 from typing import Any, Literal
 
-from pandas import DataFrame, concat
+from pandas import DataFrame, Series, concat
 
 from weaverbird.backends.pandas_executor.types import DomainRetriever, PipelineExecutor
 from weaverbird.pipeline.steps import AggregateStep
@@ -10,13 +10,17 @@ AggregateFn = Literal[
     "sum",
     "min",
     "max",
-    "count",
     "count distinct",
     "first",
     "last",
     "count distinct including empty",
 ]
 
+
+def _count_with_nulls(series: Series) -> int:
+    return series.size
+
+
 functions_aliases = {
     "avg": "mean",
     "count distinct": "nunique",
@@ -24,7 +28,9 @@ functions_aliases = {
 }
 
 
-def get_aggregate_fn(agg_function: str) -> Any:
+def get_aggregate_fn(agg_function: str, count_nulls: bool) -> Any:
+    if agg_function == "count":
+        return _count_with_nulls if count_nulls else "count"
     if agg_function in functions_aliases:
         return functions_aliases[agg_function]
     return agg_function
@@ -33,8 +39,8 @@ def get_aggregate_fn(agg_function: str) -> Any:
 def execute_aggregate(
     step: AggregateStep,
     df: DataFrame,
-    domain_retriever: DomainRetriever = None,
-    execute_pipeline: PipelineExecutor = None,
+    domain_retriever: DomainRetriever | None = None,
+    execute_pipeline: PipelineExecutor | None = None,
 ) -> DataFrame:
     group_by_columns = step.on
 
@@ -51,11 +57,9 @@ def execute_aggregate(
 
     else:
         for aggregation in step.aggregations:
-            for col, new_col in zip(aggregation.columns, aggregation.new_columns):
+            for col, new_col in zip(aggregation.columns, aggregation.new_columns, strict=True):
                 agg_serie = (
-                    grouped_by_df[col]
-                    .agg(get_aggregate_fn(aggregation.agg_function))
-                    .rename(new_col)
+                    grouped_by_df[col].agg(get_aggregate_fn(aggregation.agg_function, step.count_nulls)).rename(new_col)
                 )
                 aggregated_cols.append(agg_serie)
 
