@@ -13,13 +13,11 @@ def get_total_for_dimension(
     # get all group_by columns: all total_dimensions, except the current one + groups
     # all columns that are either not aggregated, or groups, or total will be null
     group_by_columns = step.groups + [
-        group_column.total_column
-        for group_column in step.total_dimensions
-        if group_column != total_dimension
+        group_column.total_column for group_column in step.total_dimensions if group_column != total_dimension
     ]
     aggregations = []
     for aggregation in step.aggregations:
-        agg = aggregation.copy()
+        agg = aggregation.model_copy(deep=True)
         agg.columns = agg.new_columns
         aggregations.append(agg)
 
@@ -40,9 +38,7 @@ def get_total_for_dimension(
                 full_aggregation = concat(
                     [
                         full_aggregation,
-                        get_total_for_dimension(
-                            step, aggregated_df, dimension, dimensions_to_skip + [dimension]
-                        ),
+                        get_total_for_dimension(step, aggregated_df, dimension, dimensions_to_skip + [dimension]),
                     ]
                 )
     return full_aggregation
@@ -78,7 +74,7 @@ def execute_totals(
     # rename columns in the base df, so it will match with the total in schema
     col_to_rm = set()
     for aggregation in step.aggregations:
-        for col, new_col in zip(aggregation.columns, aggregation.new_columns):
+        for col, new_col in zip(aggregation.columns, aggregation.new_columns, strict=True):
             if col != new_col:
                 df[new_col] = df[col]
                 col_to_rm.add(col)
