@@ -1,8 +1,10 @@
-from datetime import datetime
+import logging
+from datetime import UTC, datetime
 
 from numpy.ma import logical_and, logical_or
 from pandas import DataFrame, Series, Timestamp
 from pandas import to_datetime as pd_to_datetime
+from pandas.errors import OutOfBoundsDatetime
 from pandas.tseries.offsets import DateOffset
 
 from weaverbird.backends.pandas_executor.steps.utils.dates import evaluate_relative_date
@@ -23,12 +25,12 @@ def _date_bound_condition_to_tz_aware_timestamp(value: str | RelativeDate | date
     if isinstance(value, RelativeDate):
         value = evaluate_relative_date(value)
     if isinstance(value, datetime):
-        tz = value.tzinfo or "UTC"
+        tz = value.tzinfo or UTC
         # Cannot pass a tz-aware datetime object with tz arg
         return Timestamp(value.replace(tzinfo=None), tz=tz)
     else:  # str
         ts = Timestamp(value)
-        return ts if ts.tzinfo else ts.replace(tz="UTC")
+        return ts if ts.tzinfo else ts.replace(tzinfo=UTC)
 
 
 def apply_condition(condition: Condition, df: DataFrame) -> Series:
@@ -70,7 +72,15 @@ def apply_condition(condition: Condition, df: DataFrame) -> Series:
         else:
             raise NotImplementedError
 
-        value = _date_bound_condition_to_tz_aware_timestamp(condition.value)
+        try:
+            value = _date_bound_condition_to_tz_aware_timestamp(condition.value)
+        except OutOfBoundsDatetime:
+            logging.getLogger(__name__).warning(
+                f"filtering dates {condition.operator} {condition.value} is out of bound: ignoring"
+            )
+            # we're probably filtering dates using a too wide date range (eg: from year 1000 to 9999),
+            # let's assume it should return all lines unfiltered (except the null ones)
+            return df[condition.column].notnull()
 
         # Remove time info from the column to filter on. Using utc=True to ensure we have time-aware
         # objects. Since we're only using this for comparison, the input column is not modified,
@@ -78,9 +88,7 @@ def apply_condition(condition: Condition, df: DataFrame) -> Series:
             hour=0, minute=0, second=0, microsecond=0, nanosecond=0
         )
         # Do the same with the value to compare it to
-        value_without_time = value - DateOffset(
-            hour=0, minute=0, second=0, microsecond=0, nanosecond=0
-        )
+        value_without_time = value - DateOffset(hour=0, minute=0, second=0, microsecond=0, nanosecond=0)
 
         return getattr(column_without_time, comparison_method)(value_without_time)
 
