@@ -15,7 +15,7 @@ class StepExecutionReport(BaseModel):
 
 
 class PipelineExecutionReport(BaseModel):
-    steps_reports: list[StepExecutionReport] = Field(min_items=0)
+    steps_reports: list[StepExecutionReport] = Field(min_length=0)
 
 
 DomainRetriever = Callable[[str | Reference], DataFrame]
@@ -29,5 +29,4 @@ class StepExecutor(Protocol):
         df: DataFrame,
         domain_retriever: DomainRetriever | None,
         execute_pipeline: PipelineExecutor | None,
-    ) -> DataFrame:
-        ...
+    ) -> DataFrame: ...
