@@ -2,9 +2,10 @@ from enum import Enum
 
 
 class SQLDialect(str, Enum):
+    # Note: please use the same translator names than in weaverbird's frontend
     ATHENA = "athena"
-    GOOGLEBIGQUERY = "googlebigquery"
+    GOOGLEBIGQUERY = "google-big-query"
     MYSQL = "mysql"
-    POSTGRES = "postgres"
+    POSTGRES = "postgresql"
     REDSHIFT = "redshift"
     SNOWFLAKE = "snowflake"
