@@ -1,22 +1,15 @@
-from typing import TYPE_CHECKING
-
-from pypika import Field, functions
+from pypika import functions
 from pypika.dialects import PostgreSQLQuery
+from pypika.queries import Selectable
 
 from weaverbird.backends.pypika_translator.dialects import SQLDialect
 from weaverbird.backends.pypika_translator.operators import FromDateOp, RegexOp, ToDateOp
 from weaverbird.backends.pypika_translator.translators.base import (
     DataTypeMapping,
-    Self,
+    DateFormatMapping,
     SQLTranslator,
-    StepContext,
 )
 
-if TYPE_CHECKING:
-    from pypika.queries import QueryBuilder
-
-    from weaverbird.pipeline.steps import DurationStep
-
 
 class PostgreSQLTranslator(SQLTranslator):
     DIALECT = SQLDialect.POSTGRES
@@ -30,27 +23,24 @@ class PostgreSQLTranslator(SQLTranslator):
         datetime="TIMESTAMP",
         timestamp="TIMESTAMP",
     )
+    DATE_FORMAT_MAPPING = DateFormatMapping(
+        # https://www.postgresql.org/docs/current/functions-formatting.html
+        day_number="DD",
+        month_number="MM",
+        month_short="Mon",
+        # FM prefix prevents postgres from padding the month to 9 chars
+        month_full="FMMonth",
+        year="YYYY",
+    )
     SUPPORT_ROW_NUMBER = True
     SUPPORT_SPLIT_PART = True
     FROM_DATE_OP = FromDateOp.TO_CHAR
     REGEXP_OP = RegexOp.SIMILAR_TO
     TO_DATE_OP = ToDateOp.TO_TIMESTAMP
 
-    def duration(
-        self: Self,
-        *,
-        builder: "QueryBuilder",
-        prev_step_name: str,
-        columns: list[str],
-        step: "DurationStep",
-    ) -> StepContext:
-        query: "QueryBuilder" = self.QUERY_CLS.from_(prev_step_name).select(
-            *columns,
-            functions.Extract(
-                step.duration_in, Field(step.end_date_column) - Field(step.start_date_column)
-            ).as_(step.new_column_name),
-        )
-        return StepContext(query, columns + [step.new_column_name])
+    @classmethod
+    def _interval_to_seconds(cls, value: Selectable) -> functions.Function:
+        return functions.Extract("epoch", value)
 
 
 SQLTranslator.register(PostgreSQLTranslator)
