@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, TypeVar
 from pypika import functions
 from pypika.dialects import RedshiftQuery
 from pypika.enums import Dialects
-from pypika.queries import QueryBuilder, Table
+from pypika.queries import QueryBuilder
 from pypika.terms import Term
 
 from weaverbird.backends.pypika_translator.dialects import SQLDialect
@@ -12,13 +12,13 @@ from weaverbird.backends.pypika_translator.operators import FromDateOp, RegexOp
 from weaverbird.backends.pypika_translator.translators.base import (
     DataTypeMapping,
     DateAddWithoutUnderscore,
+    FromTable,
     SQLTranslator,
     StepContext,
 )
 from weaverbird.backends.pypika_translator.translators.postgresql import PostgreSQLTranslator
 
 if TYPE_CHECKING:
-
     from weaverbird.pipeline.steps import ConcatenateStep
 
 Self = TypeVar("Self", bound="RedshiftTranslator")
@@ -46,9 +46,7 @@ class RedshiftTranslator(PostgreSQLTranslator):
     # helpers allow to nest concatenations:
     # https://docs.aws.amazon.com/redshift/latest/dg/r_CONCAT.html
 
-    def _recursive_concat(
-        self, concat: functions.Concat | None, tokens: list[str]
-    ) -> functions.Concat:
+    def _recursive_concat(self, concat: functions.Concat | None, tokens: list[str]) -> functions.Concat:
         if len(tokens) == 0:
             assert concat is not None
             return concat
@@ -61,28 +59,25 @@ class RedshiftTranslator(PostgreSQLTranslator):
         self: Self,
         *,
         builder: QueryBuilder,
-        prev_step_name: str,
+        prev_step_table: FromTable,
         columns: list[str],
         step: "ConcatenateStep",
     ) -> StepContext:
         # from step.columns = ["city", "age", "username"], step.separator = " -> "
         # create [Field("city"), " -> ", Field("age"), " -> ", Field("username")]
-        the_table = Table(prev_step_name)
-        tokens = [the_table[step.columns[0]]]
+        tokens = [prev_step_table[step.columns[0]]]
         for col in step.columns[1:]:
             tokens.append(step.separator)
-            tokens.append(the_table[col])
+            tokens.append(prev_step_table[col])
 
-        query: QueryBuilder = self.QUERY_CLS.from_(prev_step_name).select(
+        query = prev_step_table.select(
             *columns,
             self._recursive_concat(None, tokens).as_(step.new_column_name),
         )
         return StepContext(query, columns + [step.new_column_name])
 
     @classmethod
-    def _add_date(
-        cls, *, target_column: Field, duration: int, unit: str, dialect: Dialects | None = None
-    ) -> Term:
+    def _add_date(cls, *, target_column: Field, duration: int, unit: str, dialect: Dialects | None = None) -> Term:
         return DateAddWithoutUnderscore(date_part=unit, interval=duration, term=target_column)
 
 
