@@ -1,4 +1,5 @@
 import operator
+from typing import TYPE_CHECKING, Any
 
 from pypika import Table
 from pypika.functions import NullIf
@@ -6,7 +7,10 @@ from pypika.terms import Term
 
 from weaverbird.pipeline.formula_ast.eval import FormulaParser
 from weaverbird.pipeline.formula_ast.types import ColumnName, Expression, Operation, Operator
-from weaverbird.pipeline.formula_ast.utils import unquote_string
+
+if TYPE_CHECKING:
+    from weaverbird.backends.pypika_translator.translators.base import FromTable
+
 
 _OP_MAP = {
     Operator.ADD: operator.add,
@@ -31,14 +35,14 @@ def _eval_expression(expr: Expression, table: Table) -> Term:
         return _eval_operation(expr, table)
     elif isinstance(expr, ColumnName):
         return table[expr.name]
-    elif isinstance(expr, str):
-        # unquoting
-        expr = unquote_string(expr)
     return Term.wrap_constant(expr)
 
 
-def formula_to_term(formula: str, table: Table) -> Term:
+def formula_to_term(formula: Any, table: "FromTable") -> Term:
     try:
         return _eval_expression(FormulaParser(formula).parse(), table)
-    except SyntaxError:  # Can happen in case formula is actually a string literal
+    except (
+        SyntaxError,
+        AttributeError,
+    ):  # Can happen in case formula is actually a string literal or a number
         return Term.wrap_constant(formula)
