@@ -1,11 +1,10 @@
 from collections.abc import Sequence
 from typing import Literal
 
-from pydantic import BaseConfig, BaseModel, Field, root_validator, validator
+from pydantic import BaseModel, ConfigDict, Field, field_validator, model_validator
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
-from weaverbird.pipeline.steps.utils.validation import validate_unique_columns
 from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 AggregateFn = Literal[
@@ -25,15 +24,16 @@ class Aggregation(BaseModel):
     new_columns: list[ColumnName] = Field(alias="newcolumns")
     agg_function: AggregateFn = Field(alias="aggfunction")
     columns: list[ColumnName]
+    model_config = ConfigDict(populate_by_name=True)
 
-    class Config(BaseConfig):
-        allow_population_by_field_name = True
+    @field_validator("columns", mode="after")
+    @classmethod
+    def validate_unique_columns(cls, columns: list[ColumnName]) -> list[ColumnName]:
+        assert len(set(columns)) == len(columns), "aggregation columns are not unique"
+        return columns
 
-    @validator("columns", pre=True)
-    def validate_unique_columns(cls, value):
-        return validate_unique_columns(value)
-
-    @root_validator(pre=True)
+    @model_validator(mode="before")
+    @classmethod
     def handle_legacy_syntax(cls, values):
         if "column" in values:
             values["columns"] = [values.pop("column")]
@@ -46,7 +46,8 @@ class AggregateStep(BaseStep):
     name: Literal["aggregate"] = "aggregate"
     on: list[ColumnName] = []
     aggregations: Sequence[Aggregation]
-    keep_original_granularity: bool | None = Field(default=False, alias="keepOriginalGranularity")
+    keep_original_granularity: bool | None = False
+    count_nulls: bool = False
 
 
 class AggregationWithVariables(Aggregation):
