@@ -9,7 +9,7 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 class ConcatenateStep(BaseStep):
     name: Literal["concatenate"] = "concatenate"
-    columns: list[ColumnName] = Field(..., min_items=2)
+    columns: list[ColumnName] = Field(..., min_length=2)
     separator: str
     new_column_name: ColumnName
 
