@@ -1,6 +1,6 @@
 from typing import Literal
 
-from pydantic import Field, root_validator
+from pydantic import Field, model_validator
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -9,11 +9,16 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 class CumSumStep(BaseStep):
     name: Literal["cumsum"] = "cumsum"
-    to_cumsum: list[tuple[str, str | None]] = Field(..., alias="toCumSum")
-    reference_column: ColumnName = Field(..., alias="referenceColumn")
-    groupby: list[ColumnName] | None
+    to_cumsum: list[tuple[str, str | None]] = Field(
+        # NOTE: alias needs to be kept here, as to_cumsum does not translate to toCumSum in CamelCase
+        ...,
+        alias="toCumSum",
+    )
+    reference_column: ColumnName
+    groupby: list[ColumnName] | None = None
 
-    @root_validator(pre=True)
+    @model_validator(mode="before")
+    @classmethod
     def handle_legacy_syntax(cls, values):
         if "valueColumn" in values:
             values["value_column"] = values.pop("valueColumn")
@@ -27,5 +32,7 @@ class CumSumStep(BaseStep):
 
 class CumSumStepWithVariable(CumSumStep, StepWithVariablesMixin):
     to_cumsum: TemplatedVariable | list[tuple[TemplatedVariable, TemplatedVariable]] = Field(
-        ..., alias="toCumSum"
+        # NOTE: alias needs to be kept here, as to_cumsum does not translate to toCumSum in CamelCase
+        ...,
+        alias="toCumSum",
     )
