@@ -4,5 +4,5 @@ from weaverbird.pipeline.steps.utils.base import BaseStep
 
 
 class CustomStep(BaseStep):
-    name: Literal['custom'] = 'custom'
+    name: Literal["custom"] = "custom"
     query: str
