@@ -1,6 +1,6 @@
 from typing import Literal
 
-from pydantic import validator
+from pydantic import field_validator
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 
@@ -8,16 +8,16 @@ from weaverbird.pipeline.steps.utils.base import BaseStep
 class CustomSqlStep(BaseStep):
     name: Literal["customsql"] = "customsql"
     query: str
+    columns: list[str] | None = None
 
     @staticmethod
     def _strip_query(query: str) -> str:
         return query.strip().strip(";")
 
-    @validator("query")
+    @field_validator("query")
+    @classmethod
     def _validate_query(cls, query: str) -> str:
-        assert ";" not in (
-            stripped := cls._strip_query(query)
-        ), "Custom SQL queries must not contain semicolumns"
+        assert ";" not in (stripped := cls._strip_query(query)), "Custom SQL queries must not contain semicolumns"
         return stripped
 
 
