@@ -23,20 +23,10 @@ BASIC_DATE_PARTS = Literal[
     "milliseconds",
 ]
 
-DATE_INFO = Union[
+
+INTEGER_DATE_PARTS = Union[  # noqa: UP007
     BASIC_DATE_PARTS,
     Literal[
-        "firstDayOfYear",
-        "firstDayOfMonth",
-        "firstDayOfWeek",
-        "firstDayOfQuarter",
-        "firstDayOfIsoWeek",
-        "previousDay",
-        "firstDayOfPreviousYear",
-        "firstDayOfPreviousMonth",
-        "firstDayOfPreviousWeek",
-        "firstDayOfPreviousQuarter",
-        "firstDayOfPreviousIsoWeek",
         "previousYear",
         "previousMonth",
         "previousWeek",
@@ -45,15 +35,34 @@ DATE_INFO = Union[
     ],
 ]
 
+TIMESTAMP_DATE_PARTS = Literal[
+    "currentDay",
+    "previousDay",
+    "firstDayOfYear",
+    "firstDayOfMonth",
+    "firstDayOfWeek",
+    "firstDayOfQuarter",
+    "firstDayOfIsoWeek",
+    "firstDayOfPreviousYear",
+    "firstDayOfPreviousMonth",
+    "firstDayOfPreviousWeek",
+    "firstDayOfPreviousQuarter",
+    "firstDayOfPreviousIsoWeek",
+]
+
+DATE_INFO = Union[  # noqa: UP007
+    INTEGER_DATE_PARTS,
+    TIMESTAMP_DATE_PARTS,
+]
+
 
 class DateExtractStep(BaseStep):
     name: Literal["dateextract"] = "dateextract"
     column: str
-    date_info: list[DATE_INFO] = Field([], alias=("dateInfo"))
-    new_columns: list[ColumnName] = Field([], alias="newColumns")
-    operation: BASIC_DATE_PARTS | None
-    new_column_name: ColumnName | None
+    date_info: list[DATE_INFO] = Field(default_factory=list)
+    new_columns: list[ColumnName] = Field(default_factory=list)
+    operation: BASIC_DATE_PARTS | None = None
+    new_column_name: ColumnName | None = None
 
 
-class DateExtractStepWithVariable(DateExtractStep, StepWithVariablesMixin):
-    ...
+class DateExtractStepWithVariable(DateExtractStep, StepWithVariablesMixin): ...
