@@ -1,7 +1,5 @@
 from typing import Literal
 
-from pydantic import Field
-
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
 from weaverbird.pipeline.types import ColumnName, TemplatedVariable
@@ -16,11 +14,11 @@ DURATIONS_IN_SECOND = {"seconds": _SECOND, "minutes": _MINUTE, "hours": _HOUR, "
 
 class DurationStep(BaseStep):
     name: Literal["duration"] = "duration"
-    new_column_name: ColumnName = Field(alias="newColumnName")
-    start_date_column: ColumnName = Field(alias="startDateColumn")
-    end_date_column: ColumnName = Field(alias="endDateColumn")
-    duration_in: Literal["seconds", "minutes", "hours", "days"] = Field(alias="durationIn")
+    new_column_name: ColumnName
+    start_date_column: ColumnName
+    end_date_column: ColumnName
+    duration_in: Literal["seconds", "minutes", "hours", "days"]
 
 
 class DurationStepWithVariable(DurationStep, StepWithVariablesMixin):
-    duration_in: TemplatedVariable = Field(alias="durationIn")
+    duration_in: TemplatedVariable
