@@ -1,6 +1,6 @@
 from typing import Any, Literal
 
-from pydantic import Field, root_validator
+from pydantic import Field, model_validator
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -9,15 +9,15 @@ from weaverbird.pipeline.types import ColumnName
 
 class FillnaStep(BaseStep):
     name: Literal["fillna"] = "fillna"
-    columns: list[ColumnName] = Field(min_items=1)
+    columns: list[ColumnName] = Field(min_length=1)
     value: Any
 
-    @root_validator(pre=True)
+    @model_validator(mode="before")
+    @classmethod
     def handle_legacy_syntax(cls, values):
         if "column" in values:
             values["columns"] = [values.pop("column")]
         return values
 
 
-class FillnaStepWithVariable(FillnaStep, StepWithVariablesMixin):
-    ...
+class FillnaStepWithVariable(FillnaStep, StepWithVariablesMixin): ...
