@@ -1,4 +1,4 @@
-from typing import List, Literal, Union
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -6,12 +6,12 @@ from weaverbird.pipeline.types import TemplatedVariable
 
 
 class PivotStep(BaseStep):
-    name: Literal['pivot'] = 'pivot'
-    index: List[str]
+    name: Literal["pivot"] = "pivot"
+    index: list[str]
     column_to_pivot: str
     value_column: str
-    agg_function: Literal['sum', 'avg', 'count', 'min', 'max']
+    agg_function: Literal["sum", "avg", "count", "min", "max"]
 
 
 class PivotStepWithVariable(PivotStep, StepWithVariablesMixin):
-    index: Union[TemplatedVariable, List[TemplatedVariable]]
+    index: TemplatedVariable | list[TemplatedVariable]
