@@ -1,7 +1,5 @@
 from typing import Literal
 
-from pydantic import Field
-
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
 from weaverbird.pipeline.types import ColumnName, TemplatedVariable
@@ -9,11 +7,11 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 class RankStep(BaseStep):
     name: Literal["rank"] = "rank"
-    value_col: ColumnName = Field(alias="valueCol")
+    value_col: ColumnName
     order: Literal["asc", "desc"]
     method: Literal["standard", "dense"]
     groupby: list[ColumnName] = []
-    new_column_name: ColumnName | None = Field(None, alias="newColumnName")
+    new_column_name: ColumnName | None = None
 
 
 class RankStepWithVariable(RankStep, StepWithVariablesMixin):
