@@ -8,4 +8,4 @@ from weaverbird.pipeline.types import ColumnName
 
 class SelectStep(BaseStep):
     name: Literal["select"] = "select"
-    columns: list[ColumnName] = Field(min_items=1)
+    columns: list[ColumnName] = Field(min_length=1)
