@@ -1,6 +1,6 @@
 from typing import Literal
 
-from pydantic import validator
+from pydantic import field_validator
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 
@@ -10,7 +10,8 @@ class SimplifyStep(BaseStep):
     # All parts of the simplified geometry will be no more than this distance from the original
     tolerance: float = 1.0
 
-    @validator("tolerance")
+    @field_validator("tolerance")
+    @classmethod
     def _tolerance_validator(cls, value: float) -> float:
         assert value > 0, "tolerance must be strictly positive"
         return value
