@@ -4,5 +4,5 @@ from weaverbird.pipeline.steps.utils.base import BaseStep
 
 
 class TableStep(BaseStep):
-    name: Literal['domain'] = 'domain'
+    name: Literal["domain"] = "domain"
     domain: str
