@@ -1,4 +1,4 @@
-from typing import List, Literal, Union
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -6,9 +6,9 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 
 class UniqueGroupsStep(BaseStep):
-    name: Literal['uniquegroups'] = 'uniquegroups'
-    on: List[ColumnName]
+    name: Literal["uniquegroups"] = "uniquegroups"
+    on: list[ColumnName]
 
 
 class UniqueGroupsStepWithVariable(UniqueGroupsStep, StepWithVariablesMixin):
-    on: Union[TemplatedVariable, List[TemplatedVariable]]
+    on: TemplatedVariable | list[TemplatedVariable]
