@@ -1,4 +1,4 @@
-from typing import List, Literal, Union
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -6,14 +6,14 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 
 class UnpivotStep(BaseStep):
-    name: Literal['unpivot'] = 'unpivot'
-    keep: List[ColumnName]
-    unpivot: List[ColumnName]
+    name: Literal["unpivot"] = "unpivot"
+    keep: list[ColumnName]
+    unpivot: list[ColumnName]
     unpivot_column_name: ColumnName
     value_column_name: ColumnName
     dropna: bool
 
 
 class UnpivotStepWithVariable(UnpivotStep, StepWithVariablesMixin):
-    keep: Union[TemplatedVariable, List[TemplatedVariable]]
-    unpivot: Union[TemplatedVariable, List[TemplatedVariable]]
+    keep: TemplatedVariable | list[TemplatedVariable]
+    unpivot: TemplatedVariable | list[TemplatedVariable]
