@@ -6,7 +6,7 @@ from .base import BaseStep
 
 class StepWithVariablesMixin:
     def render(self, variables: dict[str, Any], renderer: Callable[[Any, Any], Any]) -> BaseStep:
-        RenderedClass = self.__class__.__bases__[0]
-        step_as_dict = self.dict()  # type: ignore
+        rendered_class = self.__class__.__bases__[0]
+        step_as_dict = self.model_dump()  # type: ignore
         rendered_dict = renderer(step_as_dict, variables)
-        return RenderedClass(**rendered_dict)
+        return rendered_class(**rendered_dict)
