@@ -8,7 +8,7 @@ TYPE_WATERFALL_COLUMN = "TYPE_waterfall"
 LABEL_WATERFALL_COLUMN = "LABEL_waterfall"
 GROUP_WATERFALL_COLUMN = "GROUP_waterfall"
 
-_RESULT_COLUMN = "result"
+RESULT_COLUMN = "result"
 
 
 class WaterfallStep(BaseStep):
@@ -20,8 +20,9 @@ class WaterfallStep(BaseStep):
     labelsColumn: ColumnName
     sortBy: Literal["value", "label"]
     order: Literal["desc", "asc"]
-    parentsColumn: ColumnName | None
+    parentsColumn: ColumnName | None = None
     groupby: list[ColumnName] = []
+    backfill: bool = True
 
 
 class WaterfallStepWithVariable(WaterfallStep, StepWithVariablesMixin):
